@@ -37,7 +37,7 @@ def _tokenize_if_needed(s):
 
 
 @app.task
-def stanford_ner_tag(doc, format="tokens"):
+def stanford_ner_tag(doc, output="tokens"):
     """Named entity recognizer using Stanford NER.
 
     Currently only supports the model 'english.all.3class.distsim.crf.ser.gz'.
@@ -47,7 +47,7 @@ def stanford_ner_tag(doc, format="tokens"):
     doc : document
         Tokenization will be done by Stanford NER using its own rules.
 
-    format : string, optional
+    output : string, optional
         Output format. "tokens" gives a list of (token, nerclass) triples,
         similar to the IO format but without the "I-". "names" returns a list
         of (name, class pairs); since Stanford NER does not distinguish between
@@ -61,7 +61,7 @@ def stanford_ner_tag(doc, format="tokens"):
     """
     from ._stanford_ner import tag
     doc = fetch(doc)
-    return tag(doc, format)
+    return tag(doc, output)
 
 
 @app.task
@@ -78,6 +78,48 @@ def pos_tag(tokens, model='nltk'):
     return nltk.pos_tag([t["token"] for t in tokens])
 
 
+@app.task
+def sentiwords_tag(doc, output="bag"):
+    """Tag doc with SentiWords polarity priors.
+
+    Performs left-to-right, longest-match annotation of token spans with
+    polarities from SentiWords.
+
+    Uses no part-of-speech information; when a span has multiple possible
+    taggings in SentiWords, the mean is returned.
+
+    Parameters
+    ----------
+    doc : document or list of strings
+
+    output : string, optional
+        Output format. Either "bag" for a histogram (dict) of annotated token
+        span frequencies, or "tokens" a mixed list of strings and (list of
+        strings, polarity) pairs.
+    """
+    from ._sentiwords import tag
+    doc = _tokenize_if_needed(fetch(doc))
+
+    tagged = tag(doc)
+    if output == "bag":
+        d = {}
+        for ngram, polarity in tagged:
+            if polarity == 0:
+                continue
+            if ngram in d:
+                d[ngram][1] += 1
+            else:
+                d[ngram] = [polarity, 1]
+        return d
+
+    elif output == "tokens":
+        return [ngram if polarity == 0 else (ngram, polarity)
+                for ngram, polarity in tagged]
+
+    else:
+        raise ValueError("unknown output format %r" % output)
+
+
 @app.task
 def tokenize(doc):
     """Tokenize text.
